
User credentials in audit logs
-------

**Description:**

Whenever there are user credentials supplied in an audit log, 
this could become a risk whenever an attacker could gain access to one of these log files.


**Solution:**

Instead of storing user credentials, you may want to use user id's in order to 
identify the user in the log files.

Recommended knowledgebase item:

- Logging guidelines
